import auth0 from 'auth0-js';
import {AUTH0_DOMAIN, AUTH0_CLIENT_ID, AUTH0_CALLBACK_URL, API_IDENTIFIER} from './auth-variables';
(function() {

  function renewToken() {
    window.webAuth.renewAuth(
        {
          audience: API_IDENTIFIER,
          redirectUri: 'http://localhost:4200/callback',
          usePostMessage: true
        },
        function(err, result) {
          if (err) {
            console.log(err);
          } else {
            setSession(result);
          }
        }
    );
  }

  let tokenRenewalTimeout;
  function scheduleRenewal() {
    const expiresAt = Date.now() + 30*1000;
    // const expiresAt = JSON.parse(localStorage.getItem('expires_at'));
    const delay = expiresAt - Date.now();
    if (delay > 0) {
      tokenRenewalTimeout = setTimeout(function() {
        renewToken();
      }, delay);
    }
  }

  window.setSession = function (authResult) {
    // Set the time that the access token will expire at
    var expiresAt = JSON.stringify(
        30 * 1000 + new Date().getTime()
        // authResult.expiresIn * 1000 + new Date().getTime()
    );
    localStorage.setItem('ak_intranet_access_token', authResult.accessToken);
    localStorage.setItem('ak_intranet_id_token', authResult.idToken);
    localStorage.setItem('ak_intranet_expires_at', expiresAt);
    scheduleRenewal();
  }

  window.authOut = function () {
    // Remove tokens and expiry time from localStorage
    localStorage.removeItem('ak_intranet_access_token');
    localStorage.removeItem('ak_intranet_id_token');
    localStorage.removeItem('ak_intranet_expires_at');
    clearTimeout(tokenRenewalTimeout);
  }

  window.isAuthenticated = function () {
    // Check whether the current time is past the
    // access token's expiry time
    var expiresAt = JSON.parse(localStorage.getItem('expires_at'));
    return new Date().getTime() < expiresAt;
  }

  window.handleAuthentication = function () {
    webAuth.parseHash(window.location.hash, function(err, response) {
      parent.postMessage(err || response, 'http://localhost:4200');
      if (response && response.accessToken && response.idToken) {
        window.location.hash = '';
        setSession(response);
        console.log('respomse', response);
      } else if (err) {
        console.log(err);
        alert(
            'Error: ' + err.error + '. Check the console for further details.'
        );
      }
    });
  }

  window.webAuth = new auth0.WebAuth({
    domain: AUTH0_DOMAIN,
    clientID: AUTH0_CLIENT_ID,
    redirectUri: AUTH0_CALLBACK_URL,
    audience: 'https://' + AUTH0_DOMAIN + '/userinfo',
    responseType: 'token id_token',
    scope: 'openid',
    prompt: 'none',
    leeway: 60
  });

  handleAuthentication();
  scheduleRenewal();
})();
